<?php
  /**
  * autoload.php is automatically loaded for every page load via apache vhost
  * settings
  * 
  * @author Jon Smith <smithj@shedit.net.au>
  * @package js_sdk
  */

  include_once("config.php");
  
  /**
  * Autoload method for auto including classes when used
  * 
  * @param mixed $classname
  * @return mixed
  */
  function __autoload($classname) {
    global $cfg;
    
    $path = $cfg['installdir']."_lib/".str_replace('_', '/', $classname) . '.php';
    //echo "AUTOLOAD: $classname @ $path<br />";
    return include_once($path);
  }
  
  set_error_handler('js_debugger', E_WARNING);
  set_exception_handler('js_exception');
  ini_set("display_errors", "On");
  error_reporting(E_ALL | E_STRICT);

  /**
  * Custom error handler
  * 
  * @param mixed $errno
  * @param mixed $errstr
  * @param mixed $errfile
  * @param mixed $errline
  */
  function js_debugger($errno, $errstr, $errfile, $errline) {
    
    // This hack is in place as for some reason the @ symbol in front of @ldap_bind
    // isn't behaving as expected.
    if (strpos($errstr, "Unable to bind to server: Invalid credentials") !== false) {
      return;
    }
    
    $trace = debug_backtrace();
    unset($trace[0]);

    /* Parts of the following function have been shamelessly stolen from the iRes SDK
     * which was probably shamelessly stolen from somewhere else :-)
     *
     * From: Sdk_Debugger
     * Date: 9/Oct/2008
     */

    $trace = array_merge($trace, array());
    $n = count($trace);
    $str = "";
    for($i = 0; $i < $n; $i++) {
        $type = '';
        if (isset($trace[$i]['type'])) {
            $type = $trace[$i]['type'];
        }
        $class = '';
        if (isset($trace[$i]['class'])) {
            $class = $trace[$i]['class'];
        }
        $file = '';
        if (isset($trace[$i]['file'])) {
            $file = $trace[$i]['file'];
        }
        $line = '';
        if (isset($trace[$i]['line'])) {
            $line = $trace[$i]['line'];
        }
        $function = '';
        if (isset($trace[$i]['function'])) {
            $function = $trace[$i]['function'];
        }
        $str .= sprintf("[%s] %s(%s): %s%s%s \n",
            $i, $file, $line, $class, $type, $function);
    }

    $msg = "Warning: $errno: $errstr in $errfile on line $errline\n";
    echo "<pre>";
    echo $msg;
    echo $str;
    echo "</pre>";
    die("END ERROR - Code Execution Halted");
  }

  /**
  * Custom exception handler
  * 
  * @param mixed $exception
  */
  function js_exception($exception) {
    echo "<pre>";
    echo $exception->__toString();
    echo "</pre>";
    die("END EXCEPTION - Code Execution Halted"); 
  }
  
?>
