<?php
  /**
  * Sdk DB
  * 
  * @author Jon Smith <smithj@shedit.net.au>
  * @package js_sdk
  * @version 1.0
  */

  /**
  * Abstract class Sdk DB
  * 
  * @package js_sdk
  */
  abstract class sdk_db extends sdk { 
    protected $dbinfo;
    
    protected $dblink;
    protected $rs;
    protected $row;
    protected $currentsql;
    
    /**
    * Constructor
    * 
    * @param sdk_db_conf $dbinfo Config object, if not passed sdk_db will look for global variable
    * @return sdk_db
    */
    function __construct(sdk_db_conf $dbinfo = null) {
      if (is_null($dbinfo)) {
        global $dbconf;
        
        if (!is_object($dbconf)) {
          throw new sdk_exception_mysql("No Database Config has been supplied");
        } else {
          $this->dbinfo = $dbconf; 
        }
        
      } else {
        $this->dbinfo = $dbinfo;
      }
    }
    
    /**
    * Gets the current SQL statement loaded
    * 
    * @return string
    */
    function getcurrentsql() {
      if ($this->currentsql == "") {
        return "No Current Query";
      } else {
        return $this->currentsql;
      }
    }

    /**
    * Test for End of File
    * 
    * @return bool
    */
    function eof() {
      return (!$this->row);
    }

    /**
    * returns current row of database
    * 
    * @param bool $forTable
    * @return array
    */
    function getRow($forTable = false) {
      $temp = $this->row;

      if ($forTable) {
        foreach ($temp as $key => $value) {
          if ($value == "") {
            $temp[$key] = "&nbsp;";
          }
        }
      }

      return $temp;
    }

    /**
    * Abstract definition of sdk_db::query
    * 
    * @param string $sql SQL Statement
    */
    abstract function query($sql);

    /**
    * Abstract definition of sdk_db::getNumRows 
    */
    abstract function getNumRows();
    
    /**
    * Abstract definition of sdk_db::moveNext 
    */
    abstract function moveNext();

    /**
    * Abstract definition of sdk_db::moveFirst 
    */
    abstract function moveFirst();
    
    /**
    * Abstract definition of sdk_db::closequery 
    */
    abstract function closequery();

    /**
    * Abstract definition of sdk_db::runsql
    * 
    * @param string $runsql SQL Statement to run
    */
    abstract function runsql($runsql);

    /**
    * Abstract definition of sdk_db::getInsertID 
    */
    abstract function getInsertID();

    /**
    * Abstract definition of sdk_db::getRowsAffected 
    */
    abstract function getRowsAffected();
    
    /**
    * Abstract definition of sdk_db::escape_string
    * 
    * @param string $string String to escape
    */
    abstract function escape_string($string);

    /**
    * Abstract definition of sdk_db::deleteParm
    * 
    * @param string $parmname Name of the Parameter
    */
    abstract function deleteParm($parmname);

    /**
    * Abstract definition of sdk_db::getParm
    * 
    * @param string $parmname Name of the Parameter
    */
    abstract function getParm($parmname);

    /**
    * Abstract definition of sdk_db::setParm
    * 
    * @param string $parmname Name of the Parameter
    * @param mixed $parmvalue Value of the Patameter
    */
    abstract function setParm($parmname, $parmvalue);

    /**
    * Abstract definition of sdk_db::displayTable 
    */
    abstract function displayTable();
    
  }
  
?>