<?php
  /**
  * Sdk Logger
  * 
  * @author Jon Smith <smithj@shedit.net.au>
  * @package js_sdk
  * @version 1.0
  */
  
  /**
  * Sdk Logger
  * 
  * @package js_sdk
  * @version 1.0
  */
  class sdk_logger extends sdk {
     
    /**
    * Constructor
    * 
    * @return sdk_logger
    */
    private function __construct() {
      
    }
     
    /**
    * Register a new logger object
    * 
    * @param mixed $logname Name of the logger object
    * @param mixed $connectionstring Connection String ie file:///var/log/app.log or mysql://user:pass@host:port/db
    */
    public static function register($logname, $connectionstring) {
      $urldata = parse_url($connectionstring);
      
      if (!isset($urldata['scheme'])) {
        throw new sdk_exception_logger("Invalid log connection string $connectionstring given"); 
      }
    
      $classname = "sdk_loggerbackend_".$urldata['scheme'];
      
      if (!class_exists($classname)) {
        throw new sdk_exception_logger("No logging backend available for ".$urldata['scheme']);      
      }
      
      $objBack = new $classname($urldata);
      
      sdk_logger::managebackends($logname, $objBack);
    }
    
    /**
    * Get Instance is used to return a logger object for use
    * 
    * @param string $name Name of the logger object
    * @return sdk_loggerbackend
    */
    public static function getinstance($name) {
      return sdk_logger::managebackends($name); 
    }
    
    /**
    * Manage backends Creates and retrieves loggerbackend objects
    * 
    * @param string $name Name of the logger object
    * @param sdk_loggerbackend $objback Instantiated logger backend object
    * @return sdk_loggerbackend
    */
    private static function managebackends($name, sdk_loggerbackend $objback = null) {
      static $backends;
      
      if (!isset($backends)) {
        $backends = array(); 
      }
      
      if (!isset($objback)) {
        if (isset($backends[$name])) {
          return $backends[$name]; 
        } else {
          throw new sdk_exception_logger("The specified backend $name has not been registered");
        }
      } else {
        $backends[$name] = $objback;
      }
    }
    
    /**
    * Returns a textual representation of the logger lovel
    * 
    * @param int $loglevel Log Level
    * @return string
    */
    public static function leveltostring($loglevel) {
      switch ($loglevel) {
        case LOGGER_DEBUG:
          return "LOGGER_DEBUG";
          break;
        case LOGGER_INFO:
          return "LOGGER_INFO";
          break;
        case LOGGER_NOTICE:
          return "LOGGER_NOTICE";
          break;
        case LOGGER_WARNING:
          return "LOGGER_WARNING";
          break;
        case LOGGER_ERROR:
          return "LOGGER_ERROR";
          break;
        case LOGGER_CRITICAL:
          return "LOGGER_CRITICAL";
          break;
        default:
          return "[unknown]";
      } 
    }
  }
  
?>
